@@ -6,7 +6,7 @@
 """
 import json
 
-from mobio.libs.dyn.common.utils import Base64
+from mobio.libs.dynamic_field.common.utils import Base64
 
 
 class ESPaginate(object):
