@@ -315,20 +315,24 @@ class IBaseFilterController:
                 lst_obj_sort.append(self.__check_sort_field(item_field, order))
 
         fields = list(set(fields))
-        body = {
-            "query": query,
-            "_source": fields,
-            "sort": lst_obj_sort,
-            "size": per_page,
-        }
-        if after_token:
-            body["search_after"] = ESPaginate.parse_token(after_token)
 
-        page = es.search(
-            index=self.index,
-            doc_type=self.doc_type,
-            body=body,
-        )
+        if after_token:
+            page = es.search(
+                index=self.index,
+                query=query,
+                _source=fields,
+                sort=lst_obj_sort,
+                size=per_page,
+                search_after=ESPaginate.parse_token(after_token)
+            )
+        else:
+            page = es.search(
+                index=self.index,
+                query=query,
+                _source=fields,
+                sort=lst_obj_sort,
+                size=per_page
+            )
 
         scroll_size = page["hits"]["total"]
 
